@@ -47,6 +47,11 @@ class CreateAppGroupRequest(RpcRequest):
 
 	def set_NamespaceSource(self, NamespaceSource):  # String
 		self.add_query_param('NamespaceSource', NamespaceSource)
+	def get_ScheduleBusyWorkers(self): # Boolean
+		return self.get_query_params().get('ScheduleBusyWorkers')
+
+	def set_ScheduleBusyWorkers(self, ScheduleBusyWorkers):  # Boolean
+		self.add_query_param('ScheduleBusyWorkers', ScheduleBusyWorkers)
 	def get_GroupId(self): # String
 		return self.get_query_params().get('GroupId')
 
@@ -57,6 +62,11 @@ class CreateAppGroupRequest(RpcRequest):
 
 	def set_Description(self, Description):  # String
 		self.add_query_param('Description', Description)
+	def get_MonitorConfigJson(self): # String
+		return self.get_query_params().get('MonitorConfigJson')
+
+	def set_MonitorConfigJson(self, MonitorConfigJson):  # String
+		self.add_query_param('MonitorConfigJson', MonitorConfigJson)
 	def get_AppName(self): # String
 		return self.get_query_params().get('AppName')
 
@@ -67,8 +77,13 @@ class CreateAppGroupRequest(RpcRequest):
 
 	def set_Namespace(self, Namespace):  # String
 		self.add_query_param('Namespace', Namespace)
-	def get_AlarmJson(self): # String
-		return self.get_query_params().get('AlarmJson')
+	def get_AppKey(self): # String
+		return self.get_query_params().get('AppKey')
 
-	def set_AlarmJson(self, AlarmJson):  # String
-		self.add_query_param('AlarmJson', AlarmJson)
+	def set_AppKey(self, AppKey):  # String
+		self.add_query_param('AppKey', AppKey)
+	def get_MonitorContactsJson(self): # String
+		return self.get_query_params().get('MonitorContactsJson')
+
+	def set_MonitorContactsJson(self, MonitorContactsJson):  # String
+		self.add_query_param('MonitorContactsJson', MonitorContactsJson)
